#!/bin/bash

# Parameters
                   # Examples:
FAMILY=$1          # climate
TOOL=$2            # anomaly
UNIT_TEST=$3       # /home/test/test_30_season.py::test_anomaly (absolute path)
INT_TEST_CONFIG=$4 # /home/test/integration_config.yaml (absolute path, YAML **without** logs_location option set)
PDF_OUTPUT=$5      # /home/test/output (absolute path)

TMP_DIR=`mktemp -d`
C3S512_WP1_DATACHECKER="/data/dtrujill/git/c3s512-wp1-datachecker"

## Prepare environment
conda activate toolbox_env

## Do unit test
if [ $UNIT_TEST != 'NA' ]; then
    UNIT_LOG=$TMP_DIR/unit.json
    UNIT_TXT_1=$TMP_DIR/U1.txt
    UNIT_TXT_2=$TMP_DIR/U2.txt
    UNIT_PDF=$TMP_DIR/$FAMILY-$TOOL-unit.pdf
    echo "Running unit test. Logging to: " $UNIT_LOG
    pytest --report-log=$UNIT_LOG $UNIT_TEST
    echo "Parsing unit testing output log"
    python3 $C3S512_WP1_DATACHECKER/dqc_wrapper/scripts/json2txt_unit.py $UNIT_LOG  $UNIT_TXT_1 $UNIT_TXT_2
    echo "Generating PDF: $UNIT_PDF"
    python3 $C3S512_WP1_DATACHECKER/dqc_wrapper/scripts/txt2pdf_customTitle.py $UNIT_TXT_1 $UNIT_TXT_2 $UNIT_PDF "Summary of unit tests"

    ## Do integration test
    if [ $INT_TEST_CONFIG != 'NA' ]; then
	INT_FINAL_CONFIG=$TMP_DIR/int.yaml
	INT_TXT_1=$TMP_DIR/I1.txt
	INT_TXT_2=$TMP_DIR/I2.txt
	INT_PDF=$TMP_DIR/$FAMILY-$TOOL-integration.pdf
	echo "Setting integration tests logging output"
	echo "logs_location:" $TMP_DIR > $TMP_DIR/config_header
	tail -n +3 $INT_TEST_CONFIG > $TMP_DIR/config_body
	cat $TMP_DIR/config_header $TMP_DIR/config_body > $INT_FINAL_CONFIG
	echo "Final configuration file: $INT_FINAL_CONFIG"
	echo "Running integration test"
	run_toolbox_integration_tests -c $INT_FINAL_CONFIG -t $TOOL
	echo "Parsing integration testing output log"
	python3 $C3S512_WP1_DATACHECKER/dqc_wrapper/scripts/json2txt_integration.py $TMP_DIR/*_integration_test.json  $INT_TXT_1 $INT_TXT_2
	echo "Generating PDF: $INT_PDF"
	python3 $C3S512_WP1_DATACHECKER/dqc_wrapper/scripts/txt2pdf_customTitle.py $INT_TXT_1 $INT_TXT_2 $INT_PDF "Summary of integration tests"

	## Do CDM test
	CDM_TXT_1=$TMP_DIR/C1.txt
	CDM_TXT_2=$TMP_DIR/C2.txt
	CDM_PDF=$TMP_DIR/$FAMILY-$TOOL-compliance.pdf
	echo "Parsing CDM check output log"
	python3 $C3S512_WP1_DATACHECKER/dqc_wrapper/scripts/json2txt_cdm.py $TMP_DIR/*_integration_test.json  $CDM_TXT_1 $CDM_TXT_2
	echo "Generating PDF: $CDM_PDF"
	python3 $C3S512_WP1_DATACHECKER/dqc_wrapper/scripts/txt2pdf_customTitle.py $CDM_TXT_1 $CDM_TXT_2 $CDM_PDF "Summary of CDM compliance checks"
    else
	cp /data/docs/not-available-integration.pdf $TMP_DIR
	cp /data/docs/not-available-compliance.pdf $TMP_DIR
    fi
    
else
    cp /data/docs/not-available-unit.pdf $TMP_DIR
    cp /data/docs/not-available-integration.pdf $TMP_DIR
    cp /data/docs/not-available-compliance.pdf $TMP_DIR
fi

## Copy PDFs to selected directory
cp $TMP_DIR/*.pdf $PDF_OUTPUT
